clc
clear all
format long
t1=now;
%--------------------------------------------------------------------------
%----bandstructure of valence band for quantum well with 4*4 k.p model-----
%Reference:Hole subbands in strained GaAs-Ga(1-x)Al(x)As Quantum wells.
%Author:Reza Oliaee Rezayee,school of engineering emerging technology,Tabriz university
%-----------------------------constant-------------------------------------
h=6.626176e-34;
m0=9.109534e-31;
e=1.6e-19;
h_=h/2/pi;
h_2=h_^2;
Eps0=8.85e-12;
C0=3e8;

dz=0.2e-10;                              %number of steps
%--------------------------------------------------------------------------
%-------------------------mole fraction matrixes---------------------------
Y=[0.21  0  0.21];
X=1-Y;
%------------------------Structure Dimension & Potential-------------------
QWL=[100  100  100]*1e-10;

QWP_CB=0.65*1.247*Y;
QWP_CB=QWP_CB*1.6e-19;

QWP_VB=0.35*1.247*Y;
QWP_VB=QWP_VB*1.6e-19;   
%--------------------------------------------------------------------------
QWNUM=size(QWL,2);

N(1)=0;
for k=2:QWNUM+1;
    N(k)=int16(QWL(k-1)/dz)+N(k-1);
end;    
Ntotal=N(end)
%--------------------------------------------------------------------------
%-----------------------GaAs & Al(y)Ga(x)As parameters---------------------
%P(AlyGaxIn1-x-yAs) = P(AlAs)y + P(GaAs)x + P(InAs)(1-x-y). %Except for the
%energy bandgap, the interpolation formula of all physical parameters P
%--------------------------------------------------------------------------
g1_GaAs=6.85;
g2_GaAs=2.1;
g3_GaAs=2.9;

g1_AlAs=3.45;
g2_AlAs=0.68;
g3_AlAs=1.29;

g1_InAs=20.4;
g2_InAs=8.3;
g3_InAs=9.1;
%---------------------------------------
a_GaAs=5.653e-10;
a_AlAs=5.661e-10;
a_InAs=6.0584e-10;
%---------------------------------------
me_GaAs=0.067*m0;
me_AlAs=0.15*m0;
me_InAs=0.023*m0;
%---------------------------------------
Delta_GaAs=0.34;    %eV
Delta_AlAs=0.28;
Delta_InAs=0.38;
%---------------------------------------
%------------------------
ro=0;   %Jule  (2m/h_^2)ro^2=28.196 eV   (for GaAs)
%ro=8.22e-29;               %(2m/h_^2)ro^2=25.959 eV   (for Al(0.25)Ga(0.75)As)
%------------------------
%----------Kx & Ky-------
Kx=0;
Ky=0;
% kk=1*linspace(0,1,Ntotal);
% l=1;m=0;n=0;%X-direction
% l=0.5;m=0.5;n=0.5;%L-direction
% for Nk=1:Nt
% k=2*pi*kk(Nk)*[l m n];
%--------------------------------------------------------------------------
iii=1;
for index1=1:Ntotal
    y=Y(iii);
    x=X(iii);
    Ve=QWP_CB(iii);
    Vh=QWP_VB(iii);
    Vz=Vh;
    
    g1_AlGaInAs=g1_AlAs*(y) + g1_GaAs*(x) + g1_InAs*(1-x-y);
    g2_AlGaInAs=g2_AlAs*(y) + g2_GaAs*(x) + g2_InAs*(1-x-y);
    g3_AlGaInAs=g3_AlAs*(y) + g3_GaAs*(x) + g3_InAs*(1-x-y);
    %--------------------------------
    a_AlGaInAs=a_AlAs*(y) + a_GaAs*(x) + a_InAs*(1-x-y);
    %--------------------------------
    me_AlGaInAs=me_AlAs*(y) + me_GaAs*(x) + me_InAs*(1-x-y);
    %--------------------------------
    Eg_AlGaAs=(1.424+1.247*y)*e;    %Jule
    %--------------------------------
    %--------------------------------
    Delta_AlGaInAs=Delta_AlAs*(y) + Delta_GaAs*(x) + Delta_InAs*(1-x-y);
    Delta_AlGaInAs=Delta_AlGaInAs*e;  %Jule
    %--------------------------------
    %-----------------------3 general matrix formation---------------------
    m1=(h_2)/(2*me_AlGaInAs);
    m2=(h_2*g1_AlGaInAs)/(2*m0);
    m3=(h_2*g2_AlGaInAs)/(2*m0);
    m4=(h_2*g3_AlGaInAs)/(m0);
    %---------------------------------
    M1(1,1)=(m2*(1/(dz^2))+m3*(-2/(dz^2)));                       M1(1,2)=(-i*m4*sqrt(3)*(Kx-i*Ky)*(-1/(2*dz)));                   M1(1,3)=0;                                                      M1(1,4)=0;
    M1(2,1)=(i*m4*sqrt(3)*(Kx+i*Ky)*(-1/(2*dz)));                 M1(2,2)=(m2*(1/(dz^2))-m3*(-2/(dz^2)));                          M1(2,3)=0;                                                      M1(2,4)=0;
    M1(3,1)=0;                                                    M1(3,2)=0;                                                       M1(3,3)=(m2*(1/(dz^2))-m3*(-2/(dz^2)));                         M1(3,4)=(i*m4*sqrt(3)*(Kx-i*Ky)*(-1/(2*dz)));
    M1(4,1)=0;                                                    M1(4,2)=0;                                                       M1(4,3)=(-i*m4*sqrt(3)*(Kx+i*Ky)*(-1/(2*dz)));                  M1(4,4)=(m2*(1/(dz^2))+m3*(-2/(dz^2)));
    %----------------------------------------------------------------------
    M2(1,1)=(m2*(Kx^2+Ky^2-2/(dz^2))+m3*(Kx^2+Ky^2+4/(dz^2)))+Vz;      M2(1,2)=0;                                                              M2(1,3)=(m3*(sqrt(3)*(Kx^2-Ky^2))+i*2*sqrt(3)*m4*Kx*Ky);        M2(1,4)=0;
    M2(2,1)=0;                                                      M2(2,2)=(m2*(Kx^2+Ky^2-2/(dz^2))-m3*(Kx^2+Ky^2+4/(dz^2)))+Vz;              M2(2,3)=0;                                                      M2(2,4)=(m3*(sqrt(3)*(Kx^2-Ky^2))+i*2*sqrt(3)*m4*Kx*Ky);
    M2(3,1)=(m3*(sqrt(3)*(Kx^2-Ky^2))+i*2*sqrt(3)*m4*Kx*Ky);        M2(3,2)=0;                                                              M2(3,3)=(m2*(Kx^2+Ky^2-2/(dz^2))-m3*(Kx^2+Ky^2+4/(dz^2)))+Vz;         M2(3,4)=0;
    M2(4,1)=0;                                                      M2(4,2)=(m3*(sqrt(3)*(Kx^2-Ky^2))+i*2*sqrt(3)*m4*Kx*Ky);                M2(4,3)=0;                                                      M2(4,4)=(m2*(Kx^2+Ky^2-2/(dz^2))+m3*(Kx^2+Ky^2+4/(dz^2)))+Vz;
    %----------------------------------------------------------------------
    M3(1,1)=(m2*(1/(dz^2))+m3*(-2/(dz^2)));                    M3(1,2)=(-i*m4*sqrt(3)*(Kx-i*Ky)*(+1/(2*dz)));                M3(1,3)=0;                                                   M3(1,4)=0;
    M3(2,1)=(i*m4*sqrt(3)*(Kx+i*Ky)*(+1/(2*dz)));              M3(2,2)=(m2*(1/(dz^2))-m3*(-2/(dz^2)));                       M3(2,3)=0;                                                   M3(2,4)=0;
    M3(3,1)=0;                                                 M3(3,2)=0;                                                    M3(3,3)=(m2*(1/(dz^2))-m3*(-2/(dz^2)));                      M3(3,4)=(i*m4*sqrt(3)*(Kx-i*Ky)*(+1/(2*dz)));
    M3(4,1)=0;                                                 M3(4,2)=0;                                                    M3(4,3)=(-i*m4*sqrt(3)*(Kx+i*Ky)*(+1/(2*dz)));               M3(4,4)=(m2*(1/(dz^2))+m3*(-2/(dz^2)));
    %----------------------------------------------------------------------
    Mat1=horzcat((1)*M1,(1)*M2);              %8*16 matrix
    Mat2=horzcat((1)*M1,(1)*M2,(1)*M3);      %8*24 matrix
    Mat3=horzcat((1)*M2,(1)*M3);              %8*16 matrix
    %----------------------------------------------------------------------
     if index1==1
        SP(1:4,1:8)=Mat1;
    end
    if index1>1 & index1<Ntotal
        index2=index1-1;
        SP(index2*4+1:index2*4+4 , (index2-1)*4+1:(index2-1)*4+12)=Mat2;
    end
    if index1==N(iii+1)
        iii=iii+1;
    end
    if iii==length(N)
        SP(4*Ntotal-3:4*Ntotal,4*Ntotal-7:4*Ntotal)=Mat3;
        break;
    end
     clear M1 M2 M3 Mat1 Mat2 Mat3
end
opts.disp=0;
EE=eig(SP);
Eigen_States=(EE)*1000/e;
Energy(:,1)=Eigen_States;
N=length(Energy)
n=N/4;
L=1
for Loop=1:floor(n)
    Light_hole_valence_band(Loop,1)=Energy(L,1);
    heavy_hole_valence_band(Loop,1)=Energy(L+1,1);
    Light_hole_valence_band_s(Loop,1)=Energy(L+2,1);
    heavy_hole_valence_band_s(Loop,1)=Energy(L+3,1);
    L=L+4;
end
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
LH=sort(Light_hole_valence_band);
HH=sort(heavy_hole_valence_band);
LH_s=sort(Light_hole_valence_band_s);
HH_s=sort(heavy_hole_valence_band_s);
Energy_total=horzcat(LH,HH,LH_s,HH_s);
t2=now;
t3=datestr(t2-t1,13)





































